@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2010-2018 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2010-2020 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -243,6 +243,7 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "Löyöp"                                         => "Loyop",
    "Lü"                                            => "Lu",
    "Macaguán"                                      => "Macaguan",
+   "Magɨ (Madang Province)"                       => "Mag (Madang Province)",
    "Magdalena Peñasco Mixtec"                      => "Magdalena Penasco Mixtec",
    "Magɨyi"                                        => "Magyi",
    "Mainfränkisch"                                 => "Mainfrankisch",
@@ -283,6 +284,7 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "Ngkâlmpw Kanum"                                => "Ngkalmpw Kanum",
    "Nguôn"                                         => "Nguon",
    "Ngäbere"                                       => "Ngabere",
+   "Nǁng"                                        => "Ning",
    "Nivaclé"                                       => "Nivacle",
    "Nocamán"                                       => "Nocaman",
    "North Junín Quechua"                           => "North Junin Quechua",
