@@ -1,7 +1,7 @@
 package Locale::Codes;
 # Copyright (C) 2001      Canon Research Centre Europe (CRE).
 # Copyright (C) 2002-2009 Neil Bowers
-# Copyright (c) 2010-2019 Sullivan Beck
+# Copyright (c) 2010-2020 Sullivan Beck
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -16,7 +16,7 @@ use if $] >= 5.027007, 'deprecate';
 use Locale::Codes::Constants;
 
 our($VERSION);
-$VERSION='3.61';
+$VERSION='3.63';
 
 use Exporter qw(import);
 our(@EXPORT_OK,%EXPORT_TAGS);
@@ -62,37 +62,35 @@ sub new {
 sub show_errors {
    my($self,$val) = @_;
    $$self{'err'}  = $val;
+   return $val;
 }
 
 sub type {
    my($self,$type) = @_;
 
    if (! exists $ALL_CODESETS{$type}) {
-      # uncoverable branch false
       carp "ERROR: type: invalid argument: $type\n"  if ($$self{'err'});
-      return;
+      return 1;
    }
 
-   # uncoverable branch false
-   if (! $ALL_CODESETS{$type}{'loaded'}) {
-      my $label = $ALL_CODESETS{$type}{'module'};
-      eval "require Locale::Codes::${label}_Codes";
-      # uncoverable branch true
-      if ($@) {
-         # uncoverable statement
-         croak "ERROR: type: unable to load module: ${label}_Codes\n";
-      }
-      eval "require Locale::Codes::${label}_Retired";
-      # uncoverable branch true
-      if ($@) {
-         # uncoverable statement
-         croak "ERROR: type: unable to load module: ${label}_Retired\n";
-      }
-      $ALL_CODESETS{$type}{'loaded'} = 1;
+   my $label = $ALL_CODESETS{$type}{'module'};
+   eval "require Locale::Codes::${label}_Codes";
+   # uncoverable branch true
+   if ($@) {
+      # uncoverable statement
+      croak "ERROR: type: unable to load module: ${label}_Codes\n";
+   }
+   eval "require Locale::Codes::${label}_Retired";
+   # uncoverable branch true
+   if ($@) {
+      # uncoverable statement
+      croak "ERROR: type: unable to load module: ${label}_Retired\n";
    }
 
    $$self{'type'}    = $type;
    $$self{'codeset'} = $ALL_CODESETS{$type}{'default'};
+
+   return 0;
 }
 
 sub codeset {
@@ -100,19 +98,20 @@ sub codeset {
 
    my $type           = $$self{'type'};
    if (! exists $ALL_CODESETS{$type}{'codesets'}{$codeset}) {
-      # uncoverable branch false
       carp "ERROR: codeset: invalid argument: $codeset\n"  if ($$self{'err'});
+      return 1;
    }
 
    $$self{'codeset'}  = $codeset;
+   return 0;
 }
 
 sub version {
-  # uncoverable subroutine
-  # uncoverable statement
-  my($self) = @_;
-  # uncoverable statement
-  return $VERSION;
+   # uncoverable subroutine
+   # uncoverable statement
+   my($self) = @_;
+   # uncoverable statement
+   return $VERSION;
 }
 
 ###############################################################################
@@ -139,17 +138,13 @@ sub _code {
    $code                    = ''  if (! defined($code));
    $codeset                 = lc($codeset)  if (defined($codeset));
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
+      carp "ERROR: _code: no type set for Locale::Codes object\n"  if ($$self{'err'});
       return (1);
    }
    my $type = $$self{'type'};
    if ($codeset  &&  ! exists $ALL_CODESETS{$type}{'codesets'}{$codeset}) {
-      carp "ERROR: _code: invalid codeset provided: $codeset\n"
-        if ($$self{'err'});
+      carp "ERROR: _code: invalid codeset provided: $codeset\n"  if ($$self{'err'});
       return (1);
    }
 
@@ -162,7 +157,7 @@ sub _code {
 
    my($op,@args) = @{ $ALL_CODESETS{$type}{'codesets'}{$codeset} };
 
-   if      ($op eq 'lc') {
+   if ($op eq 'lc') {
       $code = lc($code);
    }
 
@@ -174,16 +169,13 @@ sub _code {
       $code = ucfirst(lc($code));
    }
 
-   # uncoverable branch false
    if ($op eq 'numeric') {
       if ($code =~ /^\d+$/) {
          my $l = $args[0];
          $code    = sprintf("%.${l}d", $code);
 
       } else {
-         # uncoverable statement
          carp "ERROR: _code: invalid numeric code: $code\n"  if ($$self{'err'});
-         # uncoverable statement
          return (1);
       }
    }
@@ -194,8 +186,7 @@ sub _code {
        ! exists $Data{$type}{'code2id'}{$codeset}{$code}  &&
        ! exists $Retired{$type}{$codeset}{'code'}{$code}  &&
        ! exists $Data{$type}{'codealias'}{$codeset}{$code}) {
-      carp "ERROR: _code: code not in codeset: $code [$codeset]\n"
-        if ($$self{'err'});
+      carp "ERROR: _code: code not in codeset: $code [$codeset]\n"  if ($$self{'err'});
       return (1);
    }
 
@@ -217,12 +208,9 @@ sub code2name {
       $retired       = 1;
    }
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
-      return (1);
+      carp "ERROR: code2name: no type set for Locale::Codes object\n"  if ($$self{'err'});
+      return undef;
    }
    my $type = $$self{'type'};
 
@@ -255,12 +243,9 @@ sub name2code {
       $retired       = 1;
    }
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
-      return (1);
+      carp "ERROR: name2code: no type set for Locale::Codes object\n"  if ($$self{'err'});
+      return undef;
    }
    my $type = $$self{'type'};
 
@@ -289,12 +274,9 @@ sub name2code {
 sub code2code {
    my($self,@args) = @_;
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
-      return (1);
+      carp "ERROR: code2code: no type set for Locale::Codes object\n"  if ($$self{'err'});
+      return undef;
    }
    my $type = $$self{'type'};
 
@@ -303,7 +285,6 @@ sub code2code {
    if (@args == 2) {
       ($code,$codeset2)      = @args;
       ($err,$code,$codeset1) = $self->_code($code);
-      # uncoverable branch true
       return undef  if ($err);
 
    } elsif (@args == 3) {
@@ -311,7 +292,6 @@ sub code2code {
       ($err,$code)                = $self->_code($code,$codeset1);
       return undef  if ($err);
       ($err)                      = $self->_code('',$codeset2);
-      # uncoverable branch true
       return undef  if ($err);
    }
 
@@ -331,17 +311,14 @@ sub code2code {
 sub all_codes {
    my($self,@args)   = @_;
    my $retired       = 0;
-   if (@args  &&  defined($args[$#args])  &&  lc($args[$#args]) eq 'retired') {
+   if (@args  &&  lc($args[$#args]) eq 'retired') {
       pop(@args);
       $retired       = 1;
    }
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
-      return (1);
+      carp "ERROR: all_codes: no type set for Locale::Codes object\n"  if ($$self{'err'});
+      return ();
    }
    my $type = $$self{'type'};
 
@@ -356,17 +333,14 @@ sub all_codes {
 sub all_names {
    my($self,@args)   = @_;
    my $retired       = 0;
-   if (@args  &&  defined($args[$#args])  &&  lc($args[$#args]) eq 'retired') {
+   if (@args  &&  lc($args[$#args]) eq 'retired') {
       pop(@args);
       $retired       = 1;
    }
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
-      return (1);
+      carp "ERROR: all_names: no type set for Locale::Codes object\n"  if ($$self{'err'});
+      return ();
    }
    my $type = $$self{'type'};
 
@@ -403,11 +377,8 @@ sub all_names {
 sub rename_code {
    my($self,$code,$new_name,$codeset) = @_;
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
+      carp "ERROR: rename_code: no type set for Locale::Codes object\n"  if ($$self{'err'});
       return 0;
    }
    my $type = $$self{'type'};
@@ -416,7 +387,7 @@ sub rename_code {
 
    my($err,$c,$cs) = $self->_code($code,$codeset);
    if ($err) {
-      carp "ERROR: rename: Unknown code/codeset: $code [$codeset]\n"
+      carp "ERROR: rename_code: unknown code/codeset: $code [$codeset]\n"
         if ($$self{'err'});
       return 0;
    }
@@ -441,7 +412,7 @@ sub rename_code {
       my ($new_id,$i) = @{ $Data{$type}{'alias2id'}{lc($new_name)} };
       if ($new_id != $id) {
          # Case 1
-         carp "ERROR: rename: rename to an existing name not allowed\n"
+         carp "ERROR: rename_code: rename to an existing name not allowed\n"
            if ($$self{'err'});
          return 0;
       }
@@ -473,11 +444,8 @@ sub rename_code {
 sub add_code {
    my($self,$code,$name,$codeset) = @_;
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
+      carp "ERROR: add_code: no type set for Locale::Codes object\n"  if ($$self{'err'});
       return 0;
    }
    my $type = $$self{'type'};
@@ -486,8 +454,7 @@ sub add_code {
 
    my($err,$c,$cs) = $self->_code($code,$codeset,1);
    if ($err) {
-      carp "ERROR: rename: Unknown codeset: $codeset\n"
-        if ($$self{'err'});
+      carp "ERROR: add_code: unknown codeset: $codeset\n"  if ($$self{'err'});
       return 0;
    }
   ($code,$codeset) = ($c,$cs);
@@ -496,7 +463,7 @@ sub add_code {
 
    if (exists $Data{$type}{'code2id'}{$codeset}{$code}  ||
        exists $Data{$type}{'codealias'}{$codeset}{$code}) {
-      carp "add_code: code already in use: $code\n"  if ($$self{'err'});
+      carp "ERROR: add_code: code already in use as alias: $code\n"  if ($$self{'err'});
       return 0;
    }
 
@@ -508,7 +475,7 @@ sub add_code {
    if (exists $Data{$type}{'alias2id'}{lc($name)}) {
       ($id,$i) = @{ $Data{$type}{'alias2id'}{lc($name)} };
       if (exists $Data{$type}{'id2code'}{$codeset}{$id}) {
-         carp "add_code: name already in use: $name\n"  if ($$self{'err'});
+         carp "ERROR: add_code: name already in use: $name\n"  if ($$self{'err'});
          return 0;
       }
 
@@ -536,11 +503,8 @@ sub add_code {
 sub delete_code {
    my($self,$code,$codeset) = @_;
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
+      carp "ERROR: delete_code: no type set for Locale::Codes object\n"  if ($$self{'err'});
       return 0;
    }
    my $type = $$self{'type'};
@@ -548,12 +512,9 @@ sub delete_code {
    # Make sure $code/$codeset are both valid
 
    my($err,$c,$cs) = $self->_code($code,$codeset);
-   # uncoverable branch true
    if ($err) {
-      # uncoverable statement
-      carp "ERROR: rename: Unknown code/codeset: $code [$codeset]\n"
+      carp "ERROR: delete_code: Unknown code/codeset: $code [$codeset]\n"
         if ($$self{'err'});
-      # uncoverable statement
       return 0;
    }
    ($code,$codeset) = ($c,$cs);
@@ -596,11 +557,8 @@ sub delete_code {
 sub add_alias {
    my($self,$name,$new_name) = @_;
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
+      carp "ERROR: add_alias: no type set for Locale::Codes object\n"  if ($$self{'err'});
       return 0;
    }
    my $type = $$self{'type'};
@@ -611,12 +569,12 @@ sub add_alias {
    if (exists $Data{$type}{'alias2id'}{lc($name)}) {
       $id = $Data{$type}{'alias2id'}{lc($name)}[0];
    } else {
-      carp "add_alias: name does not exist: $name\n"  if ($$self{'err'});
+      carp "ERROR: add_alias: name does not exist: $name\n"  if ($$self{'err'});
       return 0;
    }
 
    if (exists $Data{$type}{'alias2id'}{lc($new_name)}) {
-      carp "add_alias: alias already in use: $new_name\n"  if ($$self{'err'});
+      carp "ERROR: add_alias: alias already in use: $new_name\n"  if ($$self{'err'});
       return 0;
    }
 
@@ -642,11 +600,8 @@ sub add_alias {
 sub delete_alias {
    my($self,$name) = @_;
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
+      carp "ERROR: delete_alias: no type set for Locale::Codes object\n"  if ($$self{'err'});
       return 0;
    }
    my $type = $$self{'type'};
@@ -657,13 +612,13 @@ sub delete_alias {
    if (exists $Data{$type}{'alias2id'}{lc($name)}) {
       ($id,$i) = @{ $Data{$type}{'alias2id'}{lc($name)} };
    } else {
-      carp "delete_alias: name does not exist: $name\n"  if ($$self{'err'});
+      carp "ERROR: delete_alias: name does not exist: $name\n"  if ($$self{'err'});
       return 0;
    }
 
    my $n = $#{ $Data{$type}{'id2names'}{$id} } + 1;
    if ($n == 1) {
-      carp "delete_alias: only one name defined (use delete_code instead)\n"
+      carp "ERROR: delete_alias: only one name defined (use delete_code instead)\n"
         if ($$self{'err'});
       return 0;
    }
@@ -704,11 +659,8 @@ sub delete_alias {
 sub replace_code {
    my($self,$code,$new_code,$codeset) = @_;
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
+      carp "ERROR: replace_code: no type set for Locale::Codes object\n"  if ($$self{'err'});
       return 0;
    }
    my $type = $$self{'type'};
@@ -718,7 +670,7 @@ sub replace_code {
 
    my($err,$c,$cs) = $self->_code($code,$codeset);
    if ($err) {
-      carp "ERROR: rename_code: Unknown code/codeset: $code [$codeset]\n"
+      carp "ERROR: replace_code: Unknown code/codeset: $code [$codeset]\n"
         if ($$self{'err'});
       return 0;
    }
@@ -749,14 +701,14 @@ sub replace_code {
 
       } else {
          # Case 2
-         carp "rename_code: new code already in use: $new_code\n"
+         carp "ERROR: replace_code: new code already in use as alias: $new_code\n"
            if ($$self{'err'});
          return 0;
       }
 
    } elsif (exists $Data{$type}{'code2id'}{$codeset}{$new_code}) {
       # Case 3
-      carp "rename_code: new code already in use: $new_code\n"
+      carp "ERROR: replace_code: new code already in use: $new_code\n"
         if ($$self{'err'});
       return 0;
    }
@@ -784,11 +736,8 @@ sub replace_code {
 sub add_code_alias {
    my($self,$code,$new_code,$codeset) = @_;
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
+      carp "ERROR: add_code_alias: no type set for Locale::Codes object\n"  if ($$self{'err'});
       return 0;
    }
    my $type = $$self{'type'};
@@ -798,7 +747,7 @@ sub add_code_alias {
 
    my($err,$c,$cs) = $self->_code($code,$codeset);
    if ($err) {
-      carp "ERROR: add_code_alias: Unknown code/codeset: $code [$codeset]\n"
+      carp "ERROR: add_code_alias: unknown code/codeset: $code [$codeset]\n"
         if ($$self{'err'});
       return 0;
    }
@@ -810,8 +759,7 @@ sub add_code_alias {
 
    if (exists $Data{$type}{'code2id'}{$codeset}{$new_code}  ||
        exists $Data{$type}{'codealias'}{$codeset}{$new_code}) {
-      # uncoverable branch true
-      carp "add_code_alias: code already in use: $new_code\n"  if ($$self{'err'});
+      carp "ERROR: add_code_alias: code already in use: $new_code\n"  if ($$self{'err'});
       return 0;
    }
 
@@ -831,11 +779,8 @@ sub add_code_alias {
 sub delete_code_alias {
    my($self,$code,$codeset) = @_;
 
-   # uncoverable branch true
    if (! $$self{'type'}) {
-      # uncoverable statement
-      carp "ERROR: no type set for Locale::Codes object\n"  if ($$self{'err'});
-      # uncoverable statement
+      carp "ERROR: delete_code_alias: no type set for Locale::Codes object\n"  if ($$self{'err'});
       return 0;
    }
    my $type = $$self{'type'};
@@ -844,8 +789,7 @@ sub delete_code_alias {
 
    my($err,$c,$cs) = $self->_code($code,$codeset);
    if ($err) {
-      # uncoverable branch true
-      carp "ERROR: rename: Unknown code/codeset: $code [$codeset]\n"
+      carp "ERROR: delete_code_alias: unknown code/codeset: $code [$codeset]\n"
         if ($$self{'err'});
       return 0;
    }
@@ -854,8 +798,7 @@ sub delete_code_alias {
    # Check that $code exists in the codeset as an alias.
 
    if (! exists $Data{$type}{'codealias'}{$codeset}{$code}) {
-      # uncoverable branch true
-      carp "delete_code_alias(): no alias defined: $code\n"  if ($$self{'err'});
+      carp "ERROR: delete_code_alias: no alias defined: $code\n"  if ($$self{'err'});
       return 0;
    }
 
